@@ -1,6 +1,6 @@
 package Text::ANSI::Printf;
 
-our $VERSION = "2.02";
+our $VERSION = "2.03";
 
 use v5.14;
 use warnings;
@@ -15,14 +15,17 @@ sub ansi_sprintf { &sprintf(@_) }
 use Text::Conceal;
 use Text::ANSI::Fold::Util qw(ansi_width);
 
+our $REORDER = 0;
+
 sub sprintf {
     my($format, @args) = @_;
     my $conceal = Text::Conceal->new(
-	except  => $format,
-	test    => qr/[\e\b\P{ASCII}]/,
-	length  => \&ansi_width,
-	max     => int @args,
-	ordered => 0,
+	except    => $format,
+	max       => int @args,
+	test      => qr/[\e\b\P{ASCII}]/,
+	length    => \&ansi_width,
+	ordered   => ! $REORDER,
+	duplicate => !!$REORDER,
 	);
     $conceal->encode(@args) if $conceal;
     my $s = CORE::sprintf $format, @args;
@@ -47,7 +50,7 @@ Text::ANSI::Printf - printf function for string with ANSI sequence
 
 =head1 VERSION
 
-Version 2.02
+Version 2.03
 
 =head1 SYNOPSIS
 
@@ -101,6 +104,21 @@ Next code produces C<[R] [G] [B]> in proper color.
     ansi_printf("[%.1s] [%.1s] [%.1s]\n",
            "\e[31mRed\e[m", "\e[32mGreen\e[m", "\e[34mBlue\e[m");
 
+=head1 ARGUMENT REORDERING
+
+The original C<printf> function has the ability to specify the
+arguments to be targeted by the position specifier, but by default
+this module assumes that the arguments will appear in the given order,
+so you will not get the expected result. If you wish to use it, set
+the variable C<$REORDER> to 1.
+
+    $Text::ANSI::Printf::REORDER = 1;.
+
+By doing so, the order in which arguments appear can be changed and
+the same argument can be processed even if it appears more than once.
+
+This behavior is experimental and may change in the future.
+
 =head1 FUNCTIONS
 
 =over 4
